@@ -1,44 +1,26 @@
-/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: NPL 1.1/GPL 2.0/LGPL 2.1
+/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
  *
- * The contents of this file are subject to the Netscape Public License
- * Version 1.1 (the "License"); you may not use this file except in
- * compliance with the License. You may obtain a copy of the License at
- * http://www.mozilla.org/NPL/
+ * The contents of this file are subject to the Netscape Public
+ * License Version 1.1 (the "License"); you may not use this file
+ * except in compliance with the License. You may obtain a copy of
+ * the License at http://www.mozilla.org/NPL/
  *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * Software distributed under the License is distributed on an "AS
+ * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
+ * implied. See the License for the specific language governing
+ * rights and limitations under the License.
  *
  * The Original Code is mozilla.org code.
  *
- * The Initial Developer of the Original Code is 
- * Netscape Communications Corporation.
- * Portions created by the Initial Developer are Copyright (C) 1998
- * the Initial Developer. All Rights Reserved.
+ * The Initial Developer of the Original Code is Netscape
+ * Communications Corporation.  Portions created by Netscape are
+ * Copyright (C) 1998 Netscape Communications Corporation. All
+ * Rights Reserved.
  *
- * Contributor(s):
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or 
- * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the NPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the NPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+ * Contributor(s): 
+ */
 
-//mailnews.timeline_is_enabled should be set to true ONLY for perf measurement-timeline builds.
-pref("mailnews.timeline_is_enabled", false);
-
-pref("mailnews.logComposePerformance", false);
+pref("mail.showMessengerPerformance", false);
 
 pref("mail.wrap_long_lines",                true);
 pref("news.wrap_long_lines",                true);
@@ -96,43 +78,30 @@ pref("mail.identity.username",              "");
 pref("mail.identity.useremail",             "");
 pref("mail.use_fcc",                        true);
 pref("mail.cc_self",                        false);
+pref("mail.limit_message_size",             false);
+pref("mail.max_size",                       50); // download message size limit
 pref("mail.strictly_mime",                  false);
 pref("mail.strictly_mime_headers",          true);
 pref("mail.file_attach_binary",             false);
 pref("mail.show_headers",                   1); // some
 pref("mail.pane_config",                    0);
-pref("mail.addr_book.mapit_url.format", "chrome://messenger-region/locale/region.properties");
-
-// the format for "mail.addr_book.quicksearchquery.format" is:
-// @V == the escaped value typed in the quick search bar in the addressbook
-//
-// note, changing this might require a change to SearchNameOrEmail.label
-// in messenger.dtd
-pref("mail.addr_book.quicksearchquery.format","?(or(PrimaryEmail,c,@V)(DisplayName,c,@V)(FirstName,c,@V)(LastName,c,@V))");
-
-// values for "mail.addr_book.lastnamefirst" are:
-//0=displayname, 1=lastname first, 2=firstname first
-pref("mail.addr_book.lastnamefirst", 0); 
+pref("mail.addr_book.lastnamefirst", 0); //0=displayname, 1=lastname first, 2=firstname first
 pref("mail.addr_book.displayName.autoGeneration", true);
 pref("mail.addr_book.displayName.lastnamefirst", false); // generate display names in last first order
 pref("mail.attach_vcard",                   false);
 pref("mail.html_compose",                   true);
 pref("mail.compose.other.header",	    "");
-pref("mail.fcc_folder",                     "");
+localDefPref("mail.fcc_folder",                     "");
 pref("mail.encrypt_outgoing_mail",          false);
 pref("mail.crypto_sign_outgoing_mail",      false);
-pref("mail.default_html_action", 0);          // 0=ask, 1=plain, 2=html, 3=both
-pref("mail.smtp.ssl",0);                      // 0 = no, 1 = try, 2 = must use SSL
-
-pref("mail.mdn.report.not_in_to_cc", 2);               // 0: Never 1: Always 2: Ask me
-pref("mail.mdn.report.outside_domain", 2);             // 0: Never 1: Always 2: Ask me
-pref("mail.mdn.report.other", 2);                      // 0: Never 1: Always 2: Ask me 3: Denial
-
-pref("mail.incorporate.return_receipt", 0);            // 0: Inbox/filter 1: Sent folder
-pref("mail.request.return_receipt", 2);                // 1: DSN 2: MDN 3: Both
-pref("mail.receipt.request_header_type", 0);           // 0: MDN-DNT header  1: RRT header 2: Both (MC)
-pref("mail.receipt.request_return_receipt_on", false);
-pref("mail.mdn.report.enabled", true);                 // false: Never send true: Send sometimes
+pref("mail.default_html_action", 0);    // 0=ask, 1=plain, 2=html, 3=both
+pref("mail.smtp.ssl",                       0); // 0 = no, 1 = try, 2 = must use SSL
+pref("mail.mdn.report.not_in_to_cc", 0);      // 0: Never 1: Always 2: Ask me
+pref("mail.mdn.report.outside_domain", 2);    // 0: Never 1: Always 2: Ask me
+pref("mail.mdn.report.other", 2);   // 0: Never 1: Always 2: Ask me 3: Denial
+pref("mail.incorporate.return_receipt", 1); // 0: inbox/filter 1: Sent folder
+pref("mail.request.return_receipt", 2);     // 1: DSN 2: MDN 3: Both
+pref("mail.receipt.request_header_type", 0); // 0: MDN-DNT header  1: RRT header 2: Both (MC)
 
 pref("news.default_cc",                     "");
 pref("news.default_fcc",                    ""); // mailbox:URL or Imap://Host/OnlineFolderName
@@ -144,28 +113,14 @@ pref("news.max_articles",                   500);
 pref("news.mark_old_read",                  false);
 
 pref("mailnews.wraplength",                 72);
-pref("mail.compose.wrap_to_window_width",   false);
 
 pref("mailnews.reply_on_top",               0); // 0=bottom 1=top 2=select+bottom 3=select+top
 
-// 0=no header, 1="<author> wrote:", 2="On <date> <author> wrote:", 3="<author> wrote On <date>:", 4=user specified
+// 0=no header, 1="<author> wrote:", 2="On <date> <author> wrote:", 3=user specified
 pref("mailnews.reply_header_type",          1);
-// locale which affects date format, set empty string to use application default locale
-pref("mailnews.reply_header_locale",        "en-US");
-pref("mailnews.reply_header_authorwrote",   "chrome://messenger/locale/messengercompose/composeMsgs.properties");
-pref("mailnews.reply_header_ondate",        "On %s");
-// separator to separate between date and author
-pref("mailnews.reply_header_separator",     ", ");
-pref("mailnews.reply_header_colon",         ":");
-pref("mailnews.reply_header_originalmessage",   "chrome://messenger/locale/messengercompose/composeMsgs.properties");
 
 pref("mail.purge_threshhold",                100);
 pref("mail.prompt_purge_threshhold",             false);   
-
-pref("mailnews.offline_sync_mail",         false);
-pref("mailnews.offline_sync_news",         false);
-pref("mailnews.offline_sync_send_unsent",  true);
-pref("mailnews.offline_sync_work_offline", false);   
 pref("mailnews.force_ascii_search",         false);
 pref("mailnews.autolookup_unknown_mime_types",  true);
 
@@ -207,12 +162,8 @@ pref("ldap_1.directory6.attributes.telephoneNumber", "Phone Number:homephone");
 pref("ldap_1.directory6.attributes.street", "State:st");
 pref("ldap_1.directory6.filter1.repeatFilterForWords", false);
 
-pref("ldap_2.autoComplete.interval", 650);
-pref("ldap_2.autoComplete.enabled", true);
-pref("ldap_2.autoComplete.useDirectory", false);
-pref("ldap_2.autoComplete.useAddressBooks", true);
-pref("ldap_2.autoComplete.skipDirectoryIfLocalMatchFound", true);
-pref("ldap_2.autoComplete.directoryServer", "");
+pref("ldap_2.autoComplete.interval",							650);
+pref("ldap_2.autoComplete.enabled",								true);
 
 pref("ldap_2.servers.pab.position",								1);
 pref("ldap_2.servers.pab.description",							"chrome://messenger/locale/addressbook/addressBook.properties");
@@ -225,6 +176,33 @@ pref("ldap_2.servers.history.dirType",							2);
 pref("ldap_2.servers.history.isOffline",						false);
 
 
+pref("ldap_2.servers.netcenter.position",						3);
+pref("ldap_2.servers.netcenter.description",					"Netcenter Member Directory");
+pref("ldap_2.servers.netcenter.vlvDisabled",					true);
+pref("ldap_2.servers.netcenter.serverName",						"memberdir.netscape.com");
+pref("ldap_2.servers.netcenter.searchBase",						"ou=member_directory,o=netcenter.com");
+pref("ldap_2.servers.netcenter.auth.enabled",					true);
+pref("ldap_2.servers.netcenter.auth.dn",						"uid=mozilla,ou=people,o=netcenter.com");
+pref("ldap_2.servers.netcenter.auth.savePassword",				true);
+pref("ldap_2.servers.netcenter.auth.password",					"BPqvLvWNew==");
+pref("ldap_2.servers.netcenter.customDisplayUrl",				"http://dirsearch.netscape.com/cgi-bin/member_lookup.cgi?dn=%s");
+pref("ldap_2.servers.netcenter.replication.never",				true);
+
+pref("ldap_2.servers.infospace.position",						4);
+pref("ldap_2.servers.infospace.description",					"InfoSpace Directory");
+pref("ldap_2.servers.infospace.serverName",						"ldap.infospace.com");
+pref("ldap_2.servers.infospace.searchBase",						"c=US");
+pref("ldap_2.servers.infospace.vlvDisabled",					true);
+pref("ldap_2.servers.infospace.autoComplete.never",				true);
+pref("ldap_2.servers.infospace.replication.never",				true);
+
+pref("ldap_2.servers.verisign.position",						5);
+pref("ldap_2.servers.verisign.description",						"Verisign Directory");
+pref("ldap_2.servers.verisign.serverName",						"directory.verisign.com");
+pref("ldap_2.servers.verisign.vlvDisabled",						true);
+pref("ldap_2.servers.verisign.autoComplete.never",				true);
+pref("ldap_2.servers.verisign.replication.never",				true);
+
 // A position of zero is a special value that indicates the directory is deleted.
 // These entries are provided to keep the (obsolete) Four11 directory and the
 // WhoWhere, Bigfoot and Switchboard directories from being migrated.
@@ -246,7 +224,6 @@ pref("ldap_2.servers.switchboard.serverName",					"ldap.switchboard.com");
 
 pref("ldap_2.user_id",											0);
 pref("ldap_2.version",											3); /* Update kCurrentListVersion in include/dirprefs.h if you change this */
-pref("ldap_2.prefs_migrated",      false);
 
 pref("mailnews.confirm.moveFoldersToTrash", true);
 
@@ -259,31 +236,31 @@ pref("mailnews.account_central_page.url", "chrome://messenger/locale/messenger.p
 pref("mail.identity.default.compose_html", true);
 pref("mail.identity.default.valid", true);
 pref("mail.identity.default.fcc",true);
-pref("mail.identity.default.fcc_folder","mailbox://nobody@Local%20Folders/Sent");
+pref("mail.identity.default.fcc_folder","mailbox://nobody@Local Folders/Sent");
 pref("mail.identity.default.bcc_self",false);
 pref("mail.identity.default.bcc_others",false);
 pref("mail.identity.default.bcc_list","");
-pref("mail.identity.default.draft_folder","mailbox://nobody@Local%20Folders/Drafts");
-pref("mail.identity.default.stationery_folder","mailbox://nobody@Local%20Folders/Templates");
-pref("mail.identity.default.directoryServer","");
-pref("mail.identity.default.overrideGlobal_Pref", false);
+pref("mail.identity.default.draft_folder","mailbox://nobody@Local Folders/Drafts");
+pref("mail.identity.default.stationery_folder","mailbox://nobody@Local Folders/Templates");
 
+pref("mail.update_compose_title_as_you_type", true);
 
+pref("mail.collect_email_address", true);
 pref("mail.collect_email_address_incoming", true);
 pref("mail.collect_email_address_outgoing", true);
 pref("mail.collect_email_address_newsgroup", false);
 pref("mail.collect_email_address_enable_size_limit", true);
 pref("mail.collect_email_address_size_limit", 700);
-pref("mail.default_sendlater_uri","mailbox://nobody@Local%20Folders/Unsent%20Messages");
+pref("mail.default_sendlater_uri","mailbox://nobody@Local Folders/Unsent Messages");
 
 pref("mail.server.default.port", -1);
-pref("mail.server.default.offline_support_level", -1);
 pref("mail.server.default.leave_on_server", false);
 pref("mail.server.default.download_on_biff", false);
 pref("mail.server.default.check_time", 10);
 // "mail.server.default.check_new_mail" now lives in the protocol info
 pref("mail.server.default.dot_fix", true);
-pref("mail.server.default.limit_offline_message_size", false);
+pref("mail.server.default.limit_message_size", false);
+pref("mail.server.default.limit_offline_message_size", true);
 pref("mail.server.default.max_size", 50);
 pref("mail.server.default.auth_login", true);
 pref("mail.server.default.delete_mail_left_on_server", false);
@@ -296,7 +273,6 @@ pref("mail.server.default.delete_model", 1);
 pref("mail.server.default.fetch_by_chunks", true);
 pref("mail.server.default.mime_parts_on_demand", true);
 
-pref("mail.server.default.always_authenticate",false);
 pref("mail.server.default.max_articles", 500);
 pref("mail.server.default.notify.on", true);
 pref("mail.server.default.mark_old_read", false);
@@ -306,31 +282,13 @@ pref("mail.server.default.using_subscription", true);
 pref("mail.server.default.dual_use_folders", true);
 pref("mail.server.default.canDelete", false);
 pref("mail.server.default.login_at_startup", false);
-pref("mail.server.default.allows_specialfolders_usage", true);
-pref("mail.server.default.canCreateFolders", true);
-pref("mail.server.default.canFileMessages", true);
 
 pref("mail.smtpserver.default.auth_method", 1); // auth any
-pref("mail.smtpserver.default.try_ssl", 0);
+pref("mail.smtpserver.default.try_ssl", 1);
 
-// For the next 3 prefs, see <http://www.bucksch.org/1/projects/mozilla/16507>
-pref("mail.display_glyph", true);   // TXT->HTML :-) etc. in viewer
-pref("mail.display_struct", true);  // TXT->HTML *bold* etc. in viewer; ditto
-pref("mail.send_struct", false);   // HTML->HTML *bold* etc. during Send; ditto
-// For the next 4 prefs, see <http://www.bucksch.org/1/projects/mozilla/108153>
-pref("mailnews.display.prefer_plaintext", false);  // Ignore HTML parts in multipart/alternative
-pref("mailnews.display.html_as", 0);  // How to display HTML parts. 0 = Render the sender's HTML; 1 = HTML->TXT->HTML; 2 = Show HTML source; 3 = Sanitize HTML
-pref("mailnews.display.html_sanitizer.allowed_tags", "html head title body p br div(lang,title) h1 h2 h3 h4 h5 h6 ul ol li(value,start,compact) dl dt dd blockquote(type,cite) pre noscript noframes strong em sub sup span(lang,title) acronym(title) abbr(title) del(title,cite,datetime) ins(title,cite,datetime) q(cite) a(href,name,title) img(alt,title,longdesc) base(href) area(alt) applet(alt) object(alt) var samp dfn address kbd code cite s strike tt b i table(align) caption tr(align,valign) td(rowspan,colspan,align,valign) th(rowspan,colspan,align,valign)");
-pref("mailnews.display.disallow_mime_handlers", 0);  /* Let only a few classes process incoming data. This protects from bugs (e.g. buffer overflows) and from security loopholes (e.g. allowing unchecked HTML in some obscure classes, although the user has html_as > 0).
-This option is mainly for the UI of html_as.
-0 = allow all available classes
-1 = Use hardcoded blacklist to avoid rendering (incoming) HTML
-2 = ... and inline images
-3 = ... and some other uncommon content types
-100 = Use hardcoded whitelist to avoid even more bugs(buffer overflows).
-      This mode will limit the features available (e.g. uncommon
-      attachment types and inline images) and is for paranoid users.
-*/
+pref("mail.display_glyph", true);   // see <http://www.bucksch.org/1/projects/mozilla/16507>
+pref("mail.display_struct", true);  // ditto
+pref("mail.send_struct", false);   // ditto
 
 pref("mail.forward_message_mode", 0); // 0=default as attachment 2=forward as inline with attachments, (obsolete 4.x value)1=forward as quoted (mapped to 2 in mozilla)
 
@@ -350,81 +308,17 @@ pref("mailnews.nav_crosses_folders", 1); // prompt user when crossing folders
 pref("news.cancel.confirm",true);
 pref("news.cancel.alert_on_success",true);
 pref("mail.SpellCheckBeforeSend",false);
-pref("mail.warn_on_send_accel_key", true);
 pref("mail.enable_autocomplete",true);
 pref("mailnews.html_domains","");
 pref("mailnews.plaintext_domains","");
-pref("mailnews.global_html_domains.version",1);
 
+// the ui will eventually use these three prefs:
 pref("mail.biff.play_sound",true);
-pref("mail.biff.show_alert", true);
+pref("mail.biff.use_default_sound",true);
+pref("mail.biff.sound_file","");
+// must be an URL.  (provide this back door for mac users, until we have a UI
+pref("mail.biff.default_sound_url","");
 
 pref("mail.content_disposition_type", 0);
 
-pref("mailnews.show_send_progress", true); //Will show a progress dialog when saving or sending a message
-pref("mail.server.default.retainBy", 1);
-
-// for manual upgrades of certain UI features.
-// 1 -> 2 is for the folder pane tree landing, to hide the
-// unread and total columns, see msgMail3PaneWindow.js
-pref("mail.ui.folderpane.version", 1);                                          
-
-// for manual upgrades of certain UI features.
-// 1 -> 2 is for the thread pane tree landing, to hide the
-// labels column, see msgMail3PaneWindow.js
-pref("mailnews.ui.threadpane.version", 1);                                          
-// for manual upgrades of certain UI features.
-// 1 -> 2 is for the ab results pane tree landing
-// to hide the non default columns in the addressbook dialog
-// see abCommon.js and addressbook.js
-pref("mailnews.ui.addressbook_results.version", 1);                                          
-// for manual upgrades of certain UI features.
-// 1 -> 2 is for the ab results pane tree landing
-// to hide the non default columns in the addressbook sidebar panel
-// see abCommon.js and addressbook-panel.js
-pref("mailnews.ui.addressbook_panel_results.version", 1);                                          
-// for manual upgrades of certain UI features.
-// 1 -> 2 is for the ab results pane tree landing
-// to hide the non default columns in the select addresses dialog
-// see abCommon.js and abSelectAddressesDialog.js
-pref("mailnews.ui.select_addresses_results.version", 1); 
-// for manual upgrades of certain UI features.
-// 1 -> 2 is for the ab results pane
-// to hide the non default columns in the advanced directory search dialog
-// see abCommon.js and ABSearchDialog.js
-pref("mailnews.ui.advanced_directory_search_results.version", 1);                                         
-//If set to a number greater than 0, msg compose windows will be recycled in order to open them quickly
-pref("mail.compose.max_recycled_windows", 1); 
-
-// true makes it so we persist the open state of news server when starting up the 3 pane
-// this is costly, as it might result in network activity.
-// false makes it so we act like 4.x
-// see bug #103010 for details
-pref("news.persist_server_open_state_in_folderpane",false);
-
-// New color prefs for Labels
-pref("mailnews.labels.description.0", "chrome://messenger/locale/messenger.properties");
-pref("mailnews.labels.description.1", "chrome://messenger/locale/messenger.properties");
-pref("mailnews.labels.description.2", "chrome://messenger/locale/messenger.properties");
-pref("mailnews.labels.description.3", "chrome://messenger/locale/messenger.properties");
-pref("mailnews.labels.description.4", "chrome://messenger/locale/messenger.properties");
-pref("mailnews.labels.description.5", "chrome://messenger/locale/messenger.properties");
-
-// mailews.labels.color.0 is not defined because there is no color associated with
-// this particular label.  It is defined above (mailnews.lables.description.0) because
-// its description string is required in order to prepend the accesskey '0':
-//   ie: '0 None'.
-pref("mailnews.labels.color.1", "#FF0000"); // default: red
-pref("mailnews.labels.color.2", "#FF9900"); // default: orange
-pref("mailnews.labels.color.3", "#009900"); // default: green
-pref("mailnews.labels.color.4", "#3333FF"); // default: blue
-pref("mailnews.labels.color.5", "#993399"); // default: purple
-
-//default null headers
-//example "X-Warn: XReply", list of hdrs separated by ": "
-pref("mailnews.customHeaders", ""); 
-
-pref("mailnews.fakeaccount.show", false);
-pref("mailnews.fakeaccount.server", "");
-
-
+pref("mailnews.show_send_progress", false); //Will show a progress dialog when saving or sending a message
